'''
Created on 29.11.2017

@author: mschroeder
'''

import numpy as np

def match_arrays(a, b):
    """
    Find occurences of b in a.
    
    Arguments:
        a, b (np.ndarray): Arrays of matching type.
        
    Returns:
        idx_a, idx_b: Indices of matching entries in a and b.
            a[idx_a[i]] == b[idx_b[i]]

    >>> a = np.arange(100)
    >>> b = np.random.permutation(a)
    >>> idx_a, idx_b = match_arrays(a, b)
    >>> assert(np.all(a[idx_a] == b[idx_b]))

    """
    order = np.argsort(a)
    
    sorted_a = a[order]
    
    idx_sorted_a = np.searchsorted(sorted_a, b)
    
    mask = idx_sorted_a < sorted_a.shape[0]
    mask[mask] = sorted_a[idx_sorted_a[mask]] == b[mask]
    
    idx_sorted_a = idx_sorted_a[mask]
    idx_b = np.where(mask)[0]
    
    return order[idx_sorted_a], idx_b


from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="match_arrays",
    version="0.0.1",
    author="Simon-Martin Schröder",
    author_email="martin.schroeder@nerdluecht.de",
    description="Matching of Numpy arrays",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/moi90/match_arrays",
    py_modules=['match_arrays'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'numpy'
    ],
)